<?php

class DispletRetsIdxUrlStructure{
	public function create_model($setup_content = true) {
		global $displetretsidx_model;
		$model = array(
			'is_property_details_page' => is_page($displetretsidx_model['options']['property_details_page_id']),
			'is_search_results_page' => is_page($displetretsidx_model['options']['search_results_page_id']),
			'property_id' => get_query_var('property_id'),
			'property_zip' => get_query_var('property_zip'),
			'property_city' => get_query_var('property_city'),
			'property_state' => get_query_var('property_state'),
			'property_update_id' => get_query_var('property_update_id'),
			're_user_login' => get_query_var('re_user_login'),
			'use_mobile' => false
		);
		$model = array_merge($model, $displetretsidx_model);
		if (!empty($model['options']['mobile_version'])) {
			$device = new DispletRetsIdxMobileDetect();
			$model['is_mobile'] = ($device->isMobile() && !$device->isTablet()) ? true : false;
			if ((!empty($model['is_mobile']) && DispletRetsIdxMobile::user_wants_mobile() == 'true') || is_post_type_archive('rets-mobile') || is_post_type_archive('rets-mobile-contact')) {
				$mobile_model = DispletRetsIdxMobile::build_model($model);
				$model = array_merge($model, $mobile_model);
			}
		}
		if ($setup_content) {
			self::setup_content($model);
		}
		else{
			return $model;
		}
	}

	private function setup_content($model){
		$user_wants_mobile = DispletRetsIdxMobile::user_wants_mobile();
		if (!empty($model['is_mobile']) && empty($user_wants_mobile)) {
			self::prompt_for_mobile_redirect();		
		}
		if (($model['is_property_details_page'] && (!empty($model['property_id']) || !empty($model['property_zip']) || !empty($model['property_city']) || !empty($model['property_state']))) || !empty($model['property_update_id'])) {
			DispletRetsIdxPropertyDetails::build_model($model);
			if (!empty($model['property_id'])) {
				add_filter('wp_title', array('DispletRetsIdxPropertyDetails', 'replace_wp_title'), 1000000);
				add_action('wp_head', array('DispletRetsIdxPropertyDetails', 'include_jquery'));
				add_action('wp_footer', array('DispletRetsIdxPropertyDetails', 'include_property_details_popups'));
			}
			if (!empty($model['is_mobile']) && DispletRetsIdxMobile::user_wants_mobile() == 'true') {
				if (!empty($model['property_id'])) {
					add_filter('template_include', array('DispletRetsIdxPropertyDetails', 'use_mobile_template'));
				}
				else{
					add_filter('template_include', array('DispletRetsIdxSearchResults', 'use_mobile_template'));
				}
			}
			else{
				add_filter('the_title', array('DispletRetsIdxPropertyDetails', 'replace_page_title'));
				add_filter('the_content', array('DispletRetsIdxPropertyDetails', 'replace_page_content'));
			}
			self::adjust_for_genesis();
		}
		else if ($model['is_search_results_page']) {
			DispletRetsIdxSearchResults::build_model($model);
			if (!empty($model['is_mobile']) && DispletRetsIdxMobile::user_wants_mobile() == 'true') {
				add_filter('template_include', array('DispletRetsIdxSearchResults', 'use_mobile_template'));
			}
			else{
				add_filter('the_content', array('DispletRetsIdxSearchResults', 'replace_page_content'));
			}
			add_action('wp_head', array('DispletRetsIdxSearchResults', 'include_jquery'));
			add_action('wp_footer', array('DispletRetsIdxSearchResults', 'include_save_search_popup'));
			self::adjust_for_genesis();
		}
		else if (is_post_type_archive('rets-mobile')) {
			add_filter('template_include', array('DispletRetsIdxMobile', 'use_home_page_template'));
		}
		else if (is_post_type_archive('rets-mobile-contact')) {
			add_filter('template_include', array('DispletRetsIdxMobile', 'use_contact_page_template'));
		}
		else if (!empty($model['is_mobile']) && DispletRetsIdxMobile::user_wants_mobile() == 'true') {
			self::prompt_for_mobile_redirect();
		}
		if (!empty($model['property_id']) || $model['options']['allow_sitewide_registration'] == '1' || (!empty($model['is_mobile']) && DispletRetsIdxMobile::user_wants_mobile() == 'true')) {
			add_action('wp_footer', array('DispletRetsIdxPropertyDetails', 'include_login_register_popup'));
		}
	}

	public function generate_rewrite_rules(){
		global $displetretsidx_option;
		$page_slug = get_page($displetretsidx_option['property_details_page_id'])->post_name;
		add_rewrite_tag('%property_state%', '([^&]+)');
		add_rewrite_tag('%property_city%', '([^&]+)');
		add_rewrite_tag('%property_zip%', '([^&]+)');
		add_rewrite_tag('%property_id%', '([^&]+)');
		add_rewrite_tag('%property_address%', '([^&]+)');
		add_rewrite_tag('%property_update_id%', '([^&]+)');
		add_rewrite_tag('%re_user_login%', '([^&]+)');
		//$rewrite = 'index.php?pagename=' . $page_slug . '&property_state=$matches[1]&property_city=$matches[2]&property_zip=$matches[3]&property_id=$matches[4]&property_address=$matches[5]';
		add_rewrite_rule($page_slug . '/?([^/]*)/?([^/]*)/?([^/]*)/page/([0-9]+)/?$', 'index.php?page_id=' . $displetretsidx_option['property_details_page_id'] . '&property_state=$matches[1]&property_city=$matches[2]&property_zip=$matches[3]&paged=$matches[4]', 'top');
		add_rewrite_rule($page_slug . '/([^/]+)/?([^/]*)/?([^/]*)/?([^/]*)/?([^/]*)/?$', 'index.php?page_id=' . $displetretsidx_option['property_details_page_id'] . '&property_state=$matches[1]&property_city=$matches[2]&property_zip=$matches[3]&property_id=$matches[4]&property_address=$matches[5]', 'top');
		add_rewrite_rule('displet-property-update/([^/]+)/?([^/]*)/?$', 'index.php?property_update_id=$matches[1]&re_user_login=$matches[2]', 'top');
	}

	public function check_flush_rewrite_rules(){
		// Increase the flush_rewrite_version with any permalinks adjustments
		$flush_rewrite_version = get_option('displet_rets_idx_flush_rewrite_version');
		if (empty($flush_rewrite_version) || $flush_rewrite_version < 3){
			global $wp_rewrite;
			$wp_rewrite->flush_rules();
			update_option('displet_rets_idx_flush_rewrite_version', 3);
		}
	}

	public function reset_flush_rewrite_check(){
		update_option('displet_rets_idx_flush_rewrite_version', false);
	}

	public function maybe_reset_flush_rewrite($post_id){
		global $displetretsidx_option;
		if ($post_id == $displetretsidx_option['property_details_page_id']) {
			self::reset_flush_rewrite_check();
		}
	}

	public function replace_canonical(){
		global $displetretsidx_model;
		if (!empty($displetretsidx_model['property_id']) || !empty($displetretsidx_model['property_state']) || !empty($displetretsidx_model['property_city']) || !empty($displetretsidx_model['property_zip'])) {
			remove_action('wp_head', 'rel_canonical');
			add_action('wp_head', array('DispletRetsIdxUrlStructure', 'new_canonical'), 1);
		}
	}

	public function new_canonical(){
		global $displetretsidx_model;
		if (!empty($displetretsidx_model['property_id'])) {
	    	$link = $displetretsidx_model['listings'][0]->permalink;
		}
		else if (!empty($displetretsidx_model['property_zip'])) {
	    	$link = rtrim(get_permalink($displetretsidx_model['options']['property_details_page_id']), '/') . '/' .
	    		stripslashes(str_replace(' ', '-', $displetretsidx_model['property_state'])) . '/' .
	    		stripslashes(str_replace(' ', '-', $displetretsidx_model['property_city'])) . '/' .
	    		stripslashes(str_replace(' ', '-', $displetretsidx_model['property_zip']));
		}
		else if (!empty($displetretsidx_model['property_city'])) {
	    	$link = rtrim(get_permalink($displetretsidx_model['options']['property_details_page_id']), '/') . '/' .
	    		stripslashes(str_replace(' ', '-', $displetretsidx_model['property_state'])) . '/' .
	    		stripslashes(str_replace(' ', '-', $displetretsidx_model['property_city']));
		}
		else if (!empty($displetretsidx_model['property_state'])) {
	    	$link = rtrim(get_permalink($displetretsidx_model['options']['property_details_page_id']), '/') . '/' .
	    		stripslashes(str_replace(' ', '-', $displetretsidx_model['property_state']));
		}
	    echo '<link rel="canonical" href="' . esc_url($link) . '" />' . "\n";
	}

	public function remove_yoasts_canonical($canonical) {
		global $displetretsidx_model, $post;
		if (!empty($displetretsidx_model['property_id']) || !empty($displetretsidx_model['property_zip']) || !empty($displetretsidx_model['property_city']) || !empty($displetretsidx_model['property_state'])) {
	    	$canonical = false;
	    }
		return $canonical;
	}

	// Whitelist query var for Yoast's redirect option
	/* Should work but doesn't :-( - $_GET['property_id'] fails in Yoast's code, whereas get_query_var('property_id') doesn't
	function whitelist_query_var_from_yoasts_redirect($whitelisted_extravars) {
		$whitelisted_extravars = array(
			'property_state',
			'property_city',
			'property_zip',
			'property_id',
			'property_address'
		);
		return $whitelisted_extravars;
	}
	//*/

	public function redirect_to_canonical(){
		global $displetretsidx_model;
		if ((!empty($displetretsidx_model['property_id']) && !empty($displetretsidx_model['property_zip']) && !empty($displetretsidx_model['property_city']) && !empty($displetretsidx_model['property_state'])) || !empty($displetretsidx_model['property_update_id']) && !empty($displetretsidx_model['listings'][0]->permalink)) {
			$trimmed_url_end = rtrim($_SERVER['REQUEST_URI'], '/');
			$trimmed_permalink_end = rtrim(DispletRetsIdxUtilities::get_domainless_url($displetretsidx_model['listings'][0]->permalink), '/');
			if (!empty($trimmed_url_end) && !empty($trimmed_permalink_end) && $trimmed_permalink_end != $trimmed_url_end) {
				wp_safe_redirect($displetretsidx_model['listings'][0]->permalink, 301);

			}
		}
	}

	public function redirect_to_parent(){
		global $displetretsidx_model;
		if (is_page($displetretsidx_model['options']['property_details_page_id']) && !empty($displetretsidx_model['property_id'])) {
			if (empty($displetretsidx_model['listings'][0])) {
				$property_address = get_query_var('property_address');
				if ($displetretsidx_model['use_mobile']) {
					$link = rtrim(get_permalink($displetretsidx_model['options']['search_results_page_id']), '/') . '/';
				}
				else{
	    			$link = rtrim(get_permalink($displetretsidx_model['options']['property_details_page_id']), '/') . '/' .
	    				stripslashes(str_replace(' ', '-', $displetretsidx_model['property_state'])) . '/' .
	    				stripslashes(str_replace(' ', '-', $displetretsidx_model['property_city'])) . '/' .
	    				stripslashes(str_replace(' ', '-', $displetretsidx_model['property_zip']));
				}
				$link .= '#listing=' . $displetretsidx_model['property_id'] . '/';
	    		if (!empty($property_address)) {
	    			$link .= 'address=' . $property_address . '/';
	    		}
	    		$link .= 'status=unavailable';
	    		wp_safe_redirect($link, 301);
			}
			else{
				self::redirect_to_canonical();
			}
		}
		else if (!empty($displetretsidx_model['property_update_id'])) {
			self::redirect_to_canonical();
		}
	}

	private function adjust_for_genesis(){
		if (function_exists('genesis_disable_seo')) {
			genesis_disable_seo();
			global $displetretsidx_model;
			if (!empty($displetretsidx_model['property_id'])) {
				remove_filter('wp_title', 'genesis_default_title', 10, 3);
				remove_action('genesis_title', 'wp_title');
				add_action('genesis_title', array('DispletRetsIdxPropertyDetails', 'replace_wp_title_genesis'));
			}
		}
	}

	public function include_mobile_redirect_prompt(){
		echo
			'<script>
				var go_to_mobile = confirm("It appears you are using a mobile device. Would you like to navigate to the mobile-specific real estate search?");
				if (go_to_mobile === true) {
					displetretsidx.set_cookie("displetretsidx_use_mobile", "true");
				}
				else{
					displetretsidx.set_cookie("displetretsidx_use_mobile", "false");
				}
			</script>';
	}

	private function prompt_for_mobile_redirect(){
		add_action('wp_head', array('DispletRetsIdxUrlStructure', 'include_mobile_redirect_prompt'));
	}
}

// Hooking pre_get_posts for create_model is too soon for some themes/servers
add_action('wp', array('DispletRetsIdxUrlStructure', 'create_model'));
add_action('init', array('DispletRetsIdxUrlStructure', 'generate_rewrite_rules'));
add_action('wp_loaded', array('DispletRetsIdxUrlStructure', 'check_flush_rewrite_rules'));
add_action('template_redirect', array('DispletRetsIdxUrlStructure', 'replace_canonical'));
add_action('template_redirect', array('DispletRetsIdxUrlStructure', 'redirect_to_parent'), 1);
add_filter('wpseo_canonical', array('DispletRetsIdxUrlStructure', 'remove_yoasts_canonical'));
add_filter('save_post', array('DispletRetsIdxUrlStructure', 'maybe_reset_flush_rewrite'));
//add_filter('wpseo_whitelist_permalink_vars', array('DispletRetsIdxUrlStructure', 'whitelist_query_var_from_yoasts_redirect'));

?>