<?php

/*
 * Plugin name: Displet RETS/IDX
 * Plugin URI: http://displet.com/wordpress-plugins/displetreader-wordpress-plugin
 * Description: RETS/IDX Plugin that inserts real estate listings, statistics, maps, and quick searches into Wordpress pages & widget ready sidebars. Free version available.
 * Version: 2.0.13
 * Author: Displet
 * Author URI: http://displet.com/
 * License: GPL2
 */

/*  Copyright 2011 Displet (email : dev@displet.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2, as 
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

abstract class DispletRetsIdxPlugin{
	protected static $plugin_version = '2.0.13';
	protected static $api_url = 'http://api.displet.com';

	public function include_version(){
		echo '<!-- Displet RETS/IDX v. ' . self::$plugin_version . ' -->';
	}

	public function maybe_notify(){
		global $displetretsidx_option;
		$last_version = DispletRetsIdxSettings::get_option('version');
		if (version_compare('2.0.12', $last_version) > 0 && empty($displetretsidx_option['displet_app_token'])) {
			$model = array(
				'version' => '2.0.12',
				'message' => '<h3>Attention: Existing Displet Users</h3><p>Please take notice that we have recently upgraded our security procedures and have <b>added an API password</b> to your settings page. If you have already authenticated, <b>you do not need to enter a password</b>, but may wish to request the password for future use by <a href="http://displet.zendesk.com" target="_blank">submitting a ticket</a>.</p>'
			);
			echo DispletRetsIdxLoad::get_admin_template('displet-notification-jquery.php', $model);
		}
		else if (version_compare('2.0.13', $last_version) > 0 && !empty($displetretsidx_option['displet_app_key'])) {
			$model = array(
				'version' => '2.0.13',
				'message' => '<h3>New Displet Feature</h3><p>You can now view your users favorites & saved searches directly from your lead management screen. Click the details link next to each lead.</p>'
			);
			echo DispletRetsIdxLoad::get_admin_template('displet-notification-jquery.php', $model);
		}
		else if ($last_version != self::$plugin_version) {
			DispletRetsIdxSettings::update_option('version', self::$plugin_version);
		}
	}
}

add_action('wp_head', array('DispletRetsIdxPlugin', 'include_version'), 1000000);
add_action('admin_head', array('DispletRetsIdxPlugin', 'maybe_notify'));
register_activation_hook(__FILE__, array('DispletRetsIdxSettings', 'register_default_settings'));
register_activation_hook(__FILE__, array('DispletRetsIdxSearchFormWidgets', 'register_default_widgets'));
register_activation_hook(__FILE__, array('DispletRetsIdxSearchFormWidgets', 'register_default_widget_areas_content'));
register_activation_hook(__FILE__, array('DispletRetsIdxUrlStructure', 'reset_flush_rewrite_check'));
register_activation_hook(__FILE__, array('DispletRetsIdxEmails', 'adjust_activity_report_schedule'));
register_deactivation_hook(__FILE__, array('DispletRetsIdxEmails', 'unschedule_activity_report'));

require_once('displet-api.php');
require_once('displet-emails.php');
require_once('displet-email-templates.php');
require_once('displet-google-login.php');
require_once('displet-load.php');
require_once('displet-mobile.php');
require_once('includes/displet-mobile-detect.php');
require_once('displet-model.php');
require_once('displet-quick-start.php');
require_once('displet-property-details.php');
require_once('displet-residentials.php');
require_once('displet-search-results.php');
require_once('displet-search-form-widgets.php');
require_once('displet-shortcodes.php');
require_once('displet-tinymce.php');
require_once('displet-settings.php');
require_once('displet-url-structure.php');
require_once('displet-users.php');
require_once('displet-utilities.php');
require_once('displet-widgets.php');

?>